@@ -8,6 +8,10 @@ describe Gem::Tasks::Install do
     let(:path) { 'pkg/foo-1.2.3.gem' }
 
     it "should use `gem install -q`" do
+      if defined?(Bundler)
+        expect(Bundler).to receive(:with_original_env).and_yield()
+      end
+
       expect(subject).to receive(:run).with('gem', 'install', '-q', path)
 
       subject.install(path)
